/*** tws_query.h -- structs for IB/API requests
 *
 * Copyright (C) 2010-2012 Ruediger Meier
 *
 * Author:  Ruediger Meier <sweet_f_a@gmx.de>
 *
 * This file is part of twstools.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the author nor the names of any contributors
 *    may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ***/

#ifndef TWS_QUERY_H
#define TWS_QUERY_H

#include "twsapi/Contract.h"
#include "twsapi/Execution.h"
#include "twsapi/Order.h"


class ContractDetailsRequest
{
	public:
		const IB::Contract& ibContract() const;
		bool initialize( const IB::Contract& );
		
	private:
		IB::Contract _ibContract;
};




class HistRequest
{
	public:
		HistRequest();
		
		bool initialize( const IB::Contract&, const std::string &endDateTime,
			const std::string &durationStr, const std::string &barSizeSetting,
			const std::string &whatToShow, int useRTH, int formatDate );
		std::string toString() const;
		
		IB::Contract ibContract;
		std::string endDateTime;
		std::string durationStr;
		std::string barSizeSetting;
		std::string whatToShow;
		int useRTH;
		int formatDate;
};




class AccStatusRequest
{
	public:
		AccStatusRequest();
		
		bool subscribe;
		std::string acctCode;
};




class ExecutionsRequest
{
	public:
		IB::ExecutionFilter executionFilter;
};




class OrdersRequest
{
};




class PlaceOrder
{
	public:
		PlaceOrder();

		long orderId;
		int64_t time_sent;
		IB::Contract contract;
		IB::Order order;
};




class MktDataRequest
{
	public:
		MktDataRequest();

		IB::Contract ibContract;
		std::string genericTicks;
		bool snapshot;
};


#endif
